import { color, css } from '@platform/css';
import { Button } from '@platform/ui.button';
import { Hr } from '@platform/ui.dev';
import * as React from 'react';
import { Subject } from 'rxjs';
import { filter, map, takeUntil } from 'rxjs/operators';
import { FormulaInput } from '..';
const DEFAULT = {
    VALUE: '=IF(A1:B2, TRUE, FALSE) / 100',
};
export class Test extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {
            value: DEFAULT.VALUE,
        };
        this.unmounted$ = new Subject();
        this.state$ = new Subject();
        this.events$ = new Subject();
        this.inputRef = (ref) => (this.input = ref);
    }
    componentDidMount() {
        this.state$.pipe(takeUntil(this.unmounted$)).subscribe((e) => this.setState(e));
        const events$ = this.events$.pipe(takeUntil(this.unmounted$));
        events$
            .pipe(filter((e) => e.type === 'INPUT/formula/tab'), map((e) => e.payload))
            .subscribe((e) => {
        });
        events$
            .pipe(filter((e) => e.type === 'INPUT/formula/enter'), map((e) => e.payload))
            .subscribe((e) => {
            if (!e.modifierKeys.shift) {
                e.cancel();
            }
        });
        events$
            .pipe(filter((e) => e.type === 'INPUT/formula/changing'), map((e) => e.payload))
            .subscribe((e) => {
        });
        events$
            .pipe(filter((e) => e.type === 'INPUT/formula/changed'), map((e) => e.payload))
            .subscribe((e) => {
            this.state$.next({ value: e.to });
        });
    }
    componentWillUnmount() {
        this.unmounted$.next();
    }
    render() {
        const styles = {
            base: css({
                Absolute: 0,
                Flex: 'horizontal',
            }),
            left: css({
                width: 180,
                backgroundColor: color.format(-0.04),
                borderRight: `solid 1px ${color.format(-0.1)}`,
                fontSize: 14,
                padding: 10,
                lineHeight: 1.6,
            }),
            right: css({
                flex: 1,
            }),
        };
        return (React.createElement("div", Object.assign({}, styles.base),
            React.createElement("div", Object.assign({}, styles.left),
                this.button('value: <empty>', () => this.state$.next({ value: '' })),
                this.button('value: DEFAULT', () => this.state$.next({ value: DEFAULT.VALUE })),
                React.createElement(Hr, null),
                this.button('focus', () => this.input.focus()),
                this.button('selectAll', () => this.input.selectAll().focus()),
                this.button('cursorToStart', () => this.input.cursorToStart().focus()),
                this.button('cursorToEnd', () => this.input.cursorToEnd().focus())),
            React.createElement("div", Object.assign({}, styles.right), this.renderInputs())));
    }
    button(title, handler) {
        const styles = {
            base: css({ Flex: 'start-start' }),
        };
        return (React.createElement("div", Object.assign({}, styles.base),
            React.createElement(Button, { label: title, onClick: handler, block: true })));
    }
    renderInputs() {
        const styles = {
            base: css({ PaddingX: 20 }),
        };
        return (React.createElement("div", Object.assign({}, styles.base),
            this.renderInput('default - mode: "spreadsheet"', {
                focusOnLoad: true,
                selectOnLoad: true,
            }, this.inputRef),
            this.renderInput('allowTab: true', { allowTab: true }),
            this.renderInput('maxLength (4)', { maxLength: 4 }),
            this.renderInput('fontSize (16)', { fontSize: 16 }),
            this.renderInput('fontSize (8)', { fontSize: 8 }),
            this.renderInput('multiline (SHIFT + ENTER)', { multiline: true, height: 120 })));
    }
    renderInput(title, props, ref) {
        const styles = {
            base: css({
                PaddingY: 20,
                borderBottom: `solid 1px ${color.format(-0.1)}`,
            }),
            title: css({
                fontSize: 12,
                opacity: 0.5,
            }),
            body: css({
                marginLeft: 20,
                marginTop: 8,
            }),
        };
        return (React.createElement("div", Object.assign({}, styles.base),
            React.createElement("div", Object.assign({}, styles.title), title),
            React.createElement("div", Object.assign({}, styles.body),
                React.createElement(FormulaInput, Object.assign({ ref: ref, value: this.state.value, allowTab: false }, props, { "events$": this.events$ })))));
    }
}
